aboutsummaryrefslogtreecommitdiffstats
path: root/src/common/sender.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/common/sender.c')
-rw-r--r--src/common/sender.c8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/common/sender.c b/src/common/sender.c
index f63e021..62eec06 100644
--- a/src/common/sender.c
+++ b/src/common/sender.c
@@ -281,7 +281,7 @@ cant_recover:
display_wave(inst, samples[i], count);
sender_receive(inst, samples[i], count);
}
- /* do pre emphasis towards radio, not wave_write */
+ /* do pre emphasis towards radio */
if (inst->pre_emphasis)
pre_emphasis(&inst->estate, samples[i], count);
/* set paging signal */
@@ -331,9 +331,11 @@ transmit_later:
/* rx gain */
if (inst->rx_gain != 1.0)
gain_samples(samples[i], count, inst->rx_gain);
- /* do de emphasis from radio (then write_wave/wave_read), receive audio, process echo test */
- if (inst->de_emphasis)
+ /* do filter and de-emphasis from radio receive audio, process echo test */
+ if (inst->de_emphasis) {
+ dc_filter(&inst->estate, samples[i], count);
de_emphasis(&inst->estate, samples[i], count);
+ }
if (inst->loopback != 1) {
display_wave(inst, samples[i], count);
sender_receive(inst, samples[i], count);